@@ -193,7 +193,7 @@ class PrometheusEcsDiscoverer:
             if container_name == defi["name"]:
                 container_definition = defi
 
-        if toolbox.extract_env_var(container_definition, s.MARKER) == "true":
+        if _is_marked_as_target(container_definition):
             self.targets_marked_counter += 1
             _logger.debug("Prometheus marker true. Build target.")
         else:
@@ -241,6 +241,12 @@ class PrometheusEcsDiscoverer:
             env=container_definition.get("environment", [])
         )
 
+        custom_labels.update(
+            _extract_custom_labels_from_dockerlabels(
+                container_definition.get("dockerLabels", {})
+            )
+        )
+
         task_name = data.task["taskDefinitionArn"].split(":")[5].split("/")[-1]
 
         if toolbox.extract_env_var(container_definition, "PROMETHEUS_NOLABELS"):
@@ -278,6 +284,41 @@ class PrometheusEcsDiscoverer:
         )
 
 
+def _is_marked_as_target(
+    container_definition: dict,
+    marker_type: str = s.MARKER_TYPE,
+    marker: str = s.MARKER,
+) -> bool:
+    """Determines if the given container is a target.
+
+    Args:
+        container_definition (`dict`): Container definition matching the API.
+
+        marker_type (`str`, optional): Where is the marker located? Defaults to
+            `s.MARKER_TYPE`, can be set through settings.
+
+        marker (`str`, optional): The key name to look up. Must be `true`
+            string to count as marked. Defaults to `s.MARKER`, can be set
+            through settings.
+
+    Returns:
+        `bool`: Self explanatory.
+    """
+
+    if (
+        marker_type == "environment"
+        and toolbox.extract_env_var(container_definition, marker) == "true"
+    ):
+        return True
+    elif (
+        marker_type == "dockerLabels"
+        and container_definition.get("dockerLabels", {}).get(marker, None) == "true"
+    ):
+        return True
+    else:
+        return False
+
+
 def _extract_port(
     network_mode: str,
     prom_port,
@@ -345,3 +386,27 @@ def _extract_custom_labels(env: List[Dict[str, str]] or List) -> Dict[str, str]:
         if name.startswith(s.CUSTOM_LABEL_PREFIX):
             labels[name[len(s.CUSTOM_LABEL_PREFIX) :].lower()] = envvar["value"]
     return labels
+
+
+def _extract_custom_labels_from_dockerlabels(
+    docker_labels: Dict[str, str],
+    with_docker_labels: List[str] = s.WITH_DOCKER_LABELS,
+    custom_labels_key: str = s.CUSTOM_LABELS_KEY,
+    separator: str = ",",
+    equalizer: str = "=",
+) -> Dict[str, str]:
+    labels = {}
+    list_of_labels = docker_labels.get(custom_labels_key, None)
+
+    if list_of_labels:
+        elements = list_of_labels.split(separator)
+        for element in elements:
+            key, value = element.split(equalizer)
+            labels[key.strip()] = value.strip()
+
+    for label in with_docker_labels:
+        value = docker_labels.get(label, None)
+        if value:
+            labels[label.replace(".", "_").replace("-", "_")] = value
+
+    return labels
